@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.rpc import status_pb2  # type: ignore
 from google.type import color_pb2  # type: ignore
 import proto  # type: ignore
@@ -64,18 +66,18 @@ class Document(proto.Message):
         text (str):
             UTF-8 encoded text in reading order from the
             document.
-        text_styles (Sequence[google.cloud.documentai_v1beta2.types.Document.Style]):
+        text_styles (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Style]):
             Styles for the
             [Document.text][google.cloud.documentai.v1beta2.Document.text].
-        pages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page]):
+        pages (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page]):
             Visual page layout for the
             [Document][google.cloud.documentai.v1beta2.Document].
-        entities (Sequence[google.cloud.documentai_v1beta2.types.Document.Entity]):
+        entities (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Entity]):
             A list of entities detected on
             [Document.text][google.cloud.documentai.v1beta2.Document.text].
             For document shards, entities in this list may cross shard
             boundaries.
-        entity_relations (Sequence[google.cloud.documentai_v1beta2.types.Document.EntityRelation]):
+        entity_relations (MutableSequence[google.cloud.documentai_v1beta2.types.Document.EntityRelation]):
             Relationship among
             [Document.entities][google.cloud.documentai.v1beta2.Document.entities].
         shard_info (google.cloud.documentai_v1beta2.types.Document.ShardInfo):
@@ -83,7 +85,7 @@ class Document(proto.Message):
             document is sharded part of a larger document.
             If the document is not sharded, this message is
             not specified.
-        labels (Sequence[google.cloud.documentai_v1beta2.types.Document.Label]):
+        labels (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Label]):
             [Label][google.cloud.documentai.v1beta2.Document.Label]s for
             this document.
         error (google.rpc.status_pb2.Status):
@@ -107,15 +109,15 @@ class Document(proto.Message):
                 in the overall document global text.
         """
 
-        shard_index = proto.Field(
+        shard_index: int = proto.Field(
             proto.INT64,
             number=1,
         )
-        shard_count = proto.Field(
+        shard_count: int = proto.Field(
             proto.INT64,
             number=2,
         )
-        text_offset = proto.Field(
+        text_offset: int = proto.Field(
             proto.INT64,
             number=3,
         )
@@ -150,16 +152,16 @@ class Document(proto.Message):
                 assignment.
         """
 
-        automl_model = proto.Field(
+        automl_model: str = proto.Field(
             proto.STRING,
             number=2,
             oneof="source",
         )
-        name = proto.Field(
+        name: str = proto.Field(
             proto.STRING,
             number=1,
         )
-        confidence = proto.Field(
+        confidence: float = proto.Field(
             proto.FLOAT,
             number=3,
         )
@@ -200,43 +202,43 @@ class Document(proto.Message):
                     (in, px, pt, etc.).
             """
 
-            size = proto.Field(
+            size: float = proto.Field(
                 proto.FLOAT,
                 number=1,
             )
-            unit = proto.Field(
+            unit: str = proto.Field(
                 proto.STRING,
                 number=2,
             )
 
-        text_anchor = proto.Field(
+        text_anchor: "Document.TextAnchor" = proto.Field(
             proto.MESSAGE,
             number=1,
             message="Document.TextAnchor",
         )
-        color = proto.Field(
+        color: color_pb2.Color = proto.Field(
             proto.MESSAGE,
             number=2,
             message=color_pb2.Color,
         )
-        background_color = proto.Field(
+        background_color: color_pb2.Color = proto.Field(
             proto.MESSAGE,
             number=3,
             message=color_pb2.Color,
         )
-        font_weight = proto.Field(
+        font_weight: str = proto.Field(
             proto.STRING,
             number=4,
         )
-        text_style = proto.Field(
+        text_style: str = proto.Field(
             proto.STRING,
             number=5,
         )
-        text_decoration = proto.Field(
+        text_decoration: str = proto.Field(
             proto.STRING,
             number=6,
         )
-        font_size = proto.Field(
+        font_size: "Document.Style.FontSize" = proto.Field(
             proto.MESSAGE,
             number=7,
             message="Document.Style.FontSize",
@@ -258,32 +260,32 @@ class Document(proto.Message):
             layout (google.cloud.documentai_v1beta2.types.Document.Page.Layout):
                 [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                 for the page.
-            detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
+            detected_languages (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                 A list of detected languages together with
                 confidence.
-            blocks (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Block]):
+            blocks (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.Block]):
                 A list of visually detected text blocks on
                 the page. A block has a set of lines (collected
                 into paragraphs) that have a common line-spacing
                 and orientation.
-            paragraphs (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Paragraph]):
+            paragraphs (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.Paragraph]):
                 A list of visually detected text paragraphs
                 on the page. A collection of lines that a human
                 would perceive as a paragraph.
-            lines (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Line]):
+            lines (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.Line]):
                 A list of visually detected text lines on the
                 page. A collection of tokens that a human would
                 perceive as a line.
-            tokens (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Token]):
+            tokens (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.Token]):
                 A list of visually detected tokens on the
                 page.
-            visual_elements (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.VisualElement]):
+            visual_elements (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.VisualElement]):
                 A list of detected non-text visual elements
                 e.g. checkbox, signature etc. on the page.
-            tables (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Table]):
+            tables (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.Table]):
                 A list of visually detected tables on the
                 page.
-            form_fields (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.FormField]):
+            form_fields (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.FormField]):
                 A list of visually detected form fields on
                 the page.
         """
@@ -300,15 +302,15 @@ class Document(proto.Message):
                     Dimension unit.
             """
 
-            width = proto.Field(
+            width: float = proto.Field(
                 proto.FLOAT,
                 number=1,
             )
-            height = proto.Field(
+            height: float = proto.Field(
                 proto.FLOAT,
                 number=2,
             )
-            unit = proto.Field(
+            unit: str = proto.Field(
                 proto.STRING,
                 number=3,
             )
@@ -345,26 +347,26 @@ class Document(proto.Message):
                 PAGE_DOWN = 3
                 PAGE_LEFT = 4
 
-            text_anchor = proto.Field(
+            text_anchor: "Document.TextAnchor" = proto.Field(
                 proto.MESSAGE,
                 number=1,
                 message="Document.TextAnchor",
             )
-            confidence = proto.Field(
+            confidence: float = proto.Field(
                 proto.FLOAT,
                 number=2,
             )
-            bounding_poly = proto.Field(
+            bounding_poly: geometry.BoundingPoly = proto.Field(
                 proto.MESSAGE,
                 number=3,
                 message=geometry.BoundingPoly,
             )
-            orientation = proto.Field(
+            orientation: "Document.Page.Layout.Orientation" = proto.Field(
                 proto.ENUM,
                 number=4,
                 enum="Document.Page.Layout.Orientation",
             )
-            id = proto.Field(
+            id: str = proto.Field(
                 proto.STRING,
                 number=5,
             )
@@ -378,17 +380,19 @@ class Document(proto.Message):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                     for
                     [Block][google.cloud.documentai.v1beta2.Document.Page.Block].
-                detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
+                detected_languages (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages together with
                     confidence.
             """
 
-            layout = proto.Field(
+            layout: "Document.Page.Layout" = proto.Field(
                 proto.MESSAGE,
                 number=1,
                 message="Document.Page.Layout",
             )
-            detected_languages = proto.RepeatedField(
+            detected_languages: MutableSequence[
+                "Document.Page.DetectedLanguage"
+            ] = proto.RepeatedField(
                 proto.MESSAGE,
                 number=2,
                 message="Document.Page.DetectedLanguage",
@@ -403,17 +407,19 @@ class Document(proto.Message):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                     for
                     [Paragraph][google.cloud.documentai.v1beta2.Document.Page.Paragraph].
-                detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
+                detected_languages (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages together with
                     confidence.
             """
 
-            layout = proto.Field(
+            layout: "Document.Page.Layout" = proto.Field(
                 proto.MESSAGE,
                 number=1,
                 message="Document.Page.Layout",
             )
-            detected_languages = proto.RepeatedField(
+            detected_languages: MutableSequence[
+                "Document.Page.DetectedLanguage"
+            ] = proto.RepeatedField(
                 proto.MESSAGE,
                 number=2,
                 message="Document.Page.DetectedLanguage",
@@ -429,17 +435,19 @@ class Document(proto.Message):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                     for
                     [Line][google.cloud.documentai.v1beta2.Document.Page.Line].
-                detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
+                detected_languages (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages together with
                     confidence.
             """
 
-            layout = proto.Field(
+            layout: "Document.Page.Layout" = proto.Field(
                 proto.MESSAGE,
                 number=1,
                 message="Document.Page.Layout",
             )
-            detected_languages = proto.RepeatedField(
+            detected_languages: MutableSequence[
+                "Document.Page.DetectedLanguage"
+            ] = proto.RepeatedField(
                 proto.MESSAGE,
                 number=2,
                 message="Document.Page.DetectedLanguage",
@@ -456,7 +464,7 @@ class Document(proto.Message):
                 detected_break (google.cloud.documentai_v1beta2.types.Document.Page.Token.DetectedBreak):
                     Detected break at the end of a
                     [Token][google.cloud.documentai.v1beta2.Document.Page.Token].
-                detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
+                detected_languages (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages together with
                     confidence.
             """
@@ -477,23 +485,25 @@ class Document(proto.Message):
                     WIDE_SPACE = 2
                     HYPHEN = 3
 
-                type_ = proto.Field(
+                type_: "Document.Page.Token.DetectedBreak.Type" = proto.Field(
                     proto.ENUM,
                     number=1,
                     enum="Document.Page.Token.DetectedBreak.Type",
                 )
 
-            layout = proto.Field(
+            layout: "Document.Page.Layout" = proto.Field(
                 proto.MESSAGE,
                 number=1,
                 message="Document.Page.Layout",
             )
-            detected_break = proto.Field(
+            detected_break: "Document.Page.Token.DetectedBreak" = proto.Field(
                 proto.MESSAGE,
                 number=2,
                 message="Document.Page.Token.DetectedBreak",
             )
-            detected_languages = proto.RepeatedField(
+            detected_languages: MutableSequence[
+                "Document.Page.DetectedLanguage"
+            ] = proto.RepeatedField(
                 proto.MESSAGE,
                 number=3,
                 message="Document.Page.DetectedLanguage",
@@ -511,21 +521,23 @@ class Document(proto.Message):
                 type_ (str):
                     Type of the
                     [VisualElement][google.cloud.documentai.v1beta2.Document.Page.VisualElement].
-                detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
+                detected_languages (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages together with
                     confidence.
             """
 
-            layout = proto.Field(
+            layout: "Document.Page.Layout" = proto.Field(
                 proto.MESSAGE,
                 number=1,
                 message="Document.Page.Layout",
             )
-            type_ = proto.Field(
+            type_: str = proto.Field(
                 proto.STRING,
                 number=2,
             )
-            detected_languages = proto.RepeatedField(
+            detected_languages: MutableSequence[
+                "Document.Page.DetectedLanguage"
+            ] = proto.RepeatedField(
                 proto.MESSAGE,
                 number=3,
                 message="Document.Page.DetectedLanguage",
@@ -539,11 +551,11 @@ class Document(proto.Message):
                     [Layout][google.cloud.documentai.v1beta2.Document.Page.Layout]
                     for
                     [Table][google.cloud.documentai.v1beta2.Document.Page.Table].
-                header_rows (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Table.TableRow]):
+                header_rows (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.Table.TableRow]):
                     Header rows of the table.
-                body_rows (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Table.TableRow]):
+                body_rows (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.Table.TableRow]):
                     Body rows of the table.
-                detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
+                detected_languages (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages together with
                     confidence.
             """
@@ -552,11 +564,13 @@ class Document(proto.Message):
                 r"""A row of table cells.
 
                 Attributes:
-                    cells (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.Table.TableCell]):
+                    cells (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.Table.TableCell]):
                         Cells that make up this row.
                 """
 
-                cells = proto.RepeatedField(
+                cells: MutableSequence[
+                    "Document.Page.Table.TableCell"
+                ] = proto.RepeatedField(
                     proto.MESSAGE,
                     number=1,
                     message="Document.Page.Table.TableCell",
@@ -574,46 +588,54 @@ class Document(proto.Message):
                         How many rows this cell spans.
                     col_span (int):
                         How many columns this cell spans.
-                    detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
+                    detected_languages (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                         A list of detected languages together with
                         confidence.
                 """
 
-                layout = proto.Field(
+                layout: "Document.Page.Layout" = proto.Field(
                     proto.MESSAGE,
                     number=1,
                     message="Document.Page.Layout",
                 )
-                row_span = proto.Field(
+                row_span: int = proto.Field(
                     proto.INT32,
                     number=2,
                 )
-                col_span = proto.Field(
+                col_span: int = proto.Field(
                     proto.INT32,
                     number=3,
                 )
-                detected_languages = proto.RepeatedField(
+                detected_languages: MutableSequence[
+                    "Document.Page.DetectedLanguage"
+                ] = proto.RepeatedField(
                     proto.MESSAGE,
                     number=4,
                     message="Document.Page.DetectedLanguage",
                 )
 
-            layout = proto.Field(
+            layout: "Document.Page.Layout" = proto.Field(
                 proto.MESSAGE,
                 number=1,
                 message="Document.Page.Layout",
             )
-            header_rows = proto.RepeatedField(
+            header_rows: MutableSequence[
+                "Document.Page.Table.TableRow"
+            ] = proto.RepeatedField(
                 proto.MESSAGE,
                 number=2,
                 message="Document.Page.Table.TableRow",
             )
-            body_rows = proto.RepeatedField(
+            body_rows: MutableSequence[
+                "Document.Page.Table.TableRow"
+            ] = proto.RepeatedField(
                 proto.MESSAGE,
                 number=3,
                 message="Document.Page.Table.TableRow",
             )
-            detected_languages = proto.RepeatedField(
+            detected_languages: MutableSequence[
+                "Document.Page.DetectedLanguage"
+            ] = proto.RepeatedField(
                 proto.MESSAGE,
                 number=4,
                 message="Document.Page.DetectedLanguage",
@@ -634,10 +656,10 @@ class Document(proto.Message):
                     for the
                     [FormField][google.cloud.documentai.v1beta2.Document.Page.FormField]
                     value.
-                name_detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
+                name_detected_languages (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages for name
                     together with confidence.
-                value_detected_languages (Sequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
+                value_detected_languages (MutableSequence[google.cloud.documentai_v1beta2.types.Document.Page.DetectedLanguage]):
                     A list of detected languages for value
                     together with confidence.
                 value_type (str):
@@ -655,35 +677,39 @@ class Document(proto.Message):
                     export value text.
             """
 
-            field_name = proto.Field(
+            field_name: "Document.Page.Layout" = proto.Field(
                 proto.MESSAGE,
                 number=1,
                 message="Document.Page.Layout",
             )
-            field_value = proto.Field(
+            field_value: "Document.Page.Layout" = proto.Field(
                 proto.MESSAGE,
                 number=2,
                 message="Document.Page.Layout",
             )
-            name_detected_languages = proto.RepeatedField(
+            name_detected_languages: MutableSequence[
+                "Document.Page.DetectedLanguage"
+            ] = proto.RepeatedField(
                 proto.MESSAGE,
                 number=3,
                 message="Document.Page.DetectedLanguage",
             )
-            value_detected_languages = proto.RepeatedField(
+            value_detected_languages: MutableSequence[
+                "Document.Page.DetectedLanguage"
+            ] = proto.RepeatedField(
                 proto.MESSAGE,
                 number=4,
                 message="Document.Page.DetectedLanguage",
             )
-            value_type = proto.Field(
+            value_type: str = proto.Field(
                 proto.STRING,
                 number=5,
             )
-            corrected_key_text = proto.Field(
+            corrected_key_text: str = proto.Field(
                 proto.STRING,
                 number=6,
             )
-            corrected_value_text = proto.Field(
+            corrected_value_text: str = proto.Field(
                 proto.STRING,
                 number=7,
             )
@@ -700,65 +726,69 @@ class Document(proto.Message):
                     Confidence of detected language. Range [0, 1].
             """
 
-            language_code = proto.Field(
+            language_code: str = proto.Field(
                 proto.STRING,
                 number=1,
             )
-            confidence = proto.Field(
+            confidence: float = proto.Field(
                 proto.FLOAT,
                 number=2,
             )
 
-        page_number = proto.Field(
+        page_number: int = proto.Field(
             proto.INT32,
             number=1,
         )
-        dimension = proto.Field(
+        dimension: "Document.Page.Dimension" = proto.Field(
             proto.MESSAGE,
             number=2,
             message="Document.Page.Dimension",
         )
-        layout = proto.Field(
+        layout: "Document.Page.Layout" = proto.Field(
             proto.MESSAGE,
             number=3,
             message="Document.Page.Layout",
         )
-        detected_languages = proto.RepeatedField(
+        detected_languages: MutableSequence[
+            "Document.Page.DetectedLanguage"
+        ] = proto.RepeatedField(
             proto.MESSAGE,
             number=4,
             message="Document.Page.DetectedLanguage",
         )
-        blocks = proto.RepeatedField(
+        blocks: MutableSequence["Document.Page.Block"] = proto.RepeatedField(
             proto.MESSAGE,
             number=5,
             message="Document.Page.Block",
         )
-        paragraphs = proto.RepeatedField(
+        paragraphs: MutableSequence["Document.Page.Paragraph"] = proto.RepeatedField(
             proto.MESSAGE,
             number=6,
             message="Document.Page.Paragraph",
         )
-        lines = proto.RepeatedField(
+        lines: MutableSequence["Document.Page.Line"] = proto.RepeatedField(
             proto.MESSAGE,
             number=7,
             message="Document.Page.Line",
         )
-        tokens = proto.RepeatedField(
+        tokens: MutableSequence["Document.Page.Token"] = proto.RepeatedField(
             proto.MESSAGE,
             number=8,
             message="Document.Page.Token",
         )
-        visual_elements = proto.RepeatedField(
+        visual_elements: MutableSequence[
+            "Document.Page.VisualElement"
+        ] = proto.RepeatedField(
             proto.MESSAGE,
             number=9,
             message="Document.Page.VisualElement",
         )
-        tables = proto.RepeatedField(
+        tables: MutableSequence["Document.Page.Table"] = proto.RepeatedField(
             proto.MESSAGE,
             number=10,
             message="Document.Page.Table",
         )
-        form_fields = proto.RepeatedField(
+        form_fields: MutableSequence["Document.Page.FormField"] = proto.RepeatedField(
             proto.MESSAGE,
             number=11,
             message="Document.Page.FormField",
@@ -790,33 +820,33 @@ class Document(proto.Message):
                 value in the entity list for this document.
         """
 
-        text_anchor = proto.Field(
+        text_anchor: "Document.TextAnchor" = proto.Field(
             proto.MESSAGE,
             number=1,
             message="Document.TextAnchor",
         )
-        type_ = proto.Field(
+        type_: str = proto.Field(
             proto.STRING,
             number=2,
         )
-        mention_text = proto.Field(
+        mention_text: str = proto.Field(
             proto.STRING,
             number=3,
         )
-        mention_id = proto.Field(
+        mention_id: str = proto.Field(
             proto.STRING,
             number=4,
         )
-        confidence = proto.Field(
+        confidence: float = proto.Field(
             proto.FLOAT,
             number=5,
         )
-        page_anchor = proto.Field(
+        page_anchor: "Document.PageAnchor" = proto.Field(
             proto.MESSAGE,
             number=6,
             message="Document.PageAnchor",
         )
-        id = proto.Field(
+        id: str = proto.Field(
             proto.STRING,
             number=7,
         )
@@ -834,15 +864,15 @@ class Document(proto.Message):
                 Relationship description.
         """
 
-        subject_id = proto.Field(
+        subject_id: str = proto.Field(
             proto.STRING,
             number=1,
         )
-        object_id = proto.Field(
+        object_id: str = proto.Field(
             proto.STRING,
             number=2,
         )
-        relation = proto.Field(
+        relation: str = proto.Field(
             proto.STRING,
             number=3,
         )
@@ -852,7 +882,7 @@ class Document(proto.Message):
         [Document.text][google.cloud.documentai.v1beta2.Document.text].
 
         Attributes:
-            text_segments (Sequence[google.cloud.documentai_v1beta2.types.Document.TextAnchor.TextSegment]):
+            text_segments (MutableSequence[google.cloud.documentai_v1beta2.types.Document.TextAnchor.TextSegment]):
                 The text segments from the
                 [Document.text][google.cloud.documentai.v1beta2.Document.text].
             content (str):
@@ -878,21 +908,23 @@ class Document(proto.Message):
                     [Document.text][google.cloud.documentai.v1beta2.Document.text].
             """
 
-            start_index = proto.Field(
+            start_index: int = proto.Field(
                 proto.INT64,
                 number=1,
             )
-            end_index = proto.Field(
+            end_index: int = proto.Field(
                 proto.INT64,
                 number=2,
             )
 
-        text_segments = proto.RepeatedField(
+        text_segments: MutableSequence[
+            "Document.TextAnchor.TextSegment"
+        ] = proto.RepeatedField(
             proto.MESSAGE,
             number=1,
             message="Document.TextAnchor.TextSegment",
         )
-        content = proto.Field(
+        content: str = proto.Field(
             proto.STRING,
             number=2,
         )
@@ -902,7 +934,7 @@ class Document(proto.Message):
         [Document.pages][google.cloud.documentai.v1beta2.Document.pages].
 
         Attributes:
-            page_refs (Sequence[google.cloud.documentai_v1beta2.types.Document.PageAnchor.PageRef]):
+            page_refs (MutableSequence[google.cloud.documentai_v1beta2.types.Document.PageAnchor.PageRef]):
                 One or more references to visual page
                 elements
         """
@@ -939,75 +971,75 @@ class Document(proto.Message):
                 TABLE = 6
                 FORM_FIELD = 7
 
-            page = proto.Field(
+            page: int = proto.Field(
                 proto.INT64,
                 number=1,
             )
-            layout_type = proto.Field(
+            layout_type: "Document.PageAnchor.PageRef.LayoutType" = proto.Field(
                 proto.ENUM,
                 number=2,
                 enum="Document.PageAnchor.PageRef.LayoutType",
             )
-            layout_id = proto.Field(
+            layout_id: str = proto.Field(
                 proto.STRING,
                 number=3,
             )
 
-        page_refs = proto.RepeatedField(
+        page_refs: MutableSequence["Document.PageAnchor.PageRef"] = proto.RepeatedField(
             proto.MESSAGE,
             number=1,
             message="Document.PageAnchor.PageRef",
         )
 
-    uri = proto.Field(
+    uri: str = proto.Field(
         proto.STRING,
         number=1,
         oneof="source",
     )
-    content = proto.Field(
+    content: bytes = proto.Field(
         proto.BYTES,
         number=2,
         oneof="source",
     )
-    mime_type = proto.Field(
+    mime_type: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    text = proto.Field(
+    text: str = proto.Field(
         proto.STRING,
         number=4,
     )
-    text_styles = proto.RepeatedField(
+    text_styles: MutableSequence[Style] = proto.RepeatedField(
         proto.MESSAGE,
         number=5,
         message=Style,
     )
-    pages = proto.RepeatedField(
+    pages: MutableSequence[Page] = proto.RepeatedField(
         proto.MESSAGE,
         number=6,
         message=Page,
     )
-    entities = proto.RepeatedField(
+    entities: MutableSequence[Entity] = proto.RepeatedField(
         proto.MESSAGE,
         number=7,
         message=Entity,
     )
-    entity_relations = proto.RepeatedField(
+    entity_relations: MutableSequence[EntityRelation] = proto.RepeatedField(
         proto.MESSAGE,
         number=8,
         message=EntityRelation,
     )
-    shard_info = proto.Field(
+    shard_info: ShardInfo = proto.Field(
         proto.MESSAGE,
         number=9,
         message=ShardInfo,
     )
-    labels = proto.RepeatedField(
+    labels: MutableSequence[Label] = proto.RepeatedField(
         proto.MESSAGE,
         number=11,
         message=Label,
     )
-    error = proto.Field(
+    error: status_pb2.Status = proto.Field(
         proto.MESSAGE,
         number=10,
         message=status_pb2.Status,
